@@ -15,7 +15,7 @@
 #'  is `NULL` until computed by [prep.recipe()].
 #' @param limits A length 2 numeric vector defining the range to
 #'  compute the transformation parameter lambda.
-#' @param nunique An integer where data that have less possible
+#' @param num_unique An integer where data that have less possible
 #'  values will not be evaluate for a transformation.
 #' @return An updated version of `recipe` with the new step
 #'  added to the sequence of existing steps (if any). For the
@@ -23,7 +23,8 @@
 #'  selectors or variables selected) and `value` (the
 #'  lambda estimate).
 #' @keywords datagen
-#' @concept preprocessing transformation_methods
+#' @concept preprocessing
+#' @concept transformation_methods
 #' @export
 #' @details The Yeo-Johnson transformation is very similar to the
 #'  Box-Cox but does not require the input variables to be strictly
@@ -69,9 +70,10 @@
 #'   [prep.recipe()] [bake.recipe()]
 step_YeoJohnson <-
   function(recipe, ..., role = NA, trained = FALSE,
-           lambdas = NULL, limits = c(-5, 5), nunique = 5,
-           na.rm = TRUE,
-           skip = FALSE) {
+           lambdas = NULL, limits = c(-5, 5), num_unique = 5,
+           na_rm = TRUE,
+           skip = FALSE,
+           id = rand_id("YeoJohnson")) {
     add_step(
       recipe,
       step_YeoJohnson_new(
@@ -80,18 +82,16 @@ step_YeoJohnson <-
         trained = trained,
         lambdas = lambdas,
         limits = sort(limits)[1:2],
-        nunique = nunique,
-        na.rm = na.rm,
-        skip = skip
+        num_unique = num_unique,
+        na_rm = na_rm,
+        skip = skip,
+        id = id
       )
     )
   }
 
 step_YeoJohnson_new <-
-  function(terms = NULL, role = NA, trained = FALSE,
-           lambdas = NULL, limits = NULL, nunique = NULL,
-           na.rm = NULL,
-           skip = FALSE) {
+  function(terms, role, trained, lambdas, limits, num_unique, na_rm, skip, id) {
     step(
       subclass = "YeoJohnson",
       terms = terms,
@@ -99,9 +99,10 @@ step_YeoJohnson_new <-
       trained = trained,
       lambdas = lambdas,
       limits = limits,
-      nunique = nunique,
-      na.rm = na.rm,
-      skip = skip
+      num_unique = num_unique,
+      na_rm = na_rm,
+      skip = skip,
+      id = id
     )
   }
 
@@ -115,8 +116,8 @@ prep.step_YeoJohnson <- function(x, training, info = NULL, ...) {
     estimate_yj,
     c(lambda = 0),
     limits = x$limits,
-    nunique = x$nunique,
-    na.rm = x$na.rm
+    num_unique = x$num_unique,
+    na_rm = x$na_rm
   )
   values <- values[!is.na(values)]
   step_YeoJohnson_new(
@@ -125,22 +126,23 @@ prep.step_YeoJohnson <- function(x, training, info = NULL, ...) {
     trained = TRUE,
     lambdas = values,
     limits = x$limits,
-    nunique = x$nunique,
-    na.rm = x$na.rm,
-    skip = x$skip
+    num_unique = x$num_unique,
+    na_rm = x$na_rm,
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @export
-bake.step_YeoJohnson <- function(object, newdata, ...) {
+bake.step_YeoJohnson <- function(object, new_data, ...) {
   if (length(object$lambdas) == 0)
-    return(as_tibble(newdata))
+    return(as_tibble(new_data))
   param <- names(object$lambdas)
   for (i in seq_along(object$lambdas))
-    newdata[, param[i]] <-
-    yj_trans(getElement(newdata, param[i]),
+    new_data[, param[i]] <-
+    yj_trans(getElement(new_data, param[i]),
              lambda = object$lambdas[param[i]])
-  as_tibble(newdata)
+  as_tibble(new_data)
 }
 
 print.step_YeoJohnson <-
@@ -220,19 +222,19 @@ yj_obj <- function(lam, dat){
 #' @export
 #' @keywords internal
 #' @rdname recipes-internal
-estimate_yj <- function(dat, limits = c(-5, 5), nunique = 5,
-                        na.rm = TRUE) {
+estimate_yj <- function(dat, limits = c(-5, 5), num_unique = 5,
+                        na_rm = TRUE) {
   na_rows <- which(is.na(dat))
   if (length(na_rows) > 0) {
-    if (na.rm) {
+    if (na_rm) {
       dat <- dat[-na_rows]
     } else {
-      stop("Missing values in data. See `na.rm` option", call. = FALSE)
+      stop("Missing values in data. See `na_rm` option", call. = FALSE)
     }
   }
 
   eps <- .001
-  if (length(unique(dat)) < nunique)
+  if (length(unique(dat)) < num_unique)
     return(NA)
   res <- optimize(
     yj_obj,
@@ -250,4 +252,5 @@ estimate_yj <- function(dat, limits = c(-5, 5), nunique = 5,
 
 #' @rdname step_YeoJohnson
 #' @param x A `step_YeoJohnson` object.
+#' @export
 tidy.step_YeoJohnson <- tidy.step_BoxCox
