@@ -84,3 +84,21 @@ NULL
 #' data(covers)
 #' str(covers)
 NULL
+
+#' Smithsonian Museums
+#'
+#' Geocodes for the Smithsonian museums (circa 2018). 
+#' 
+#' @name Smithsonian
+#' @aliases Smithsonian
+#' @docType data
+#' @return \item{Smithsonian}{a tibble}
+#'
+#' @source https://en.wikipedia.org/wiki/List_of_Smithsonian_museums
+#'
+#' @keywords datasets
+#' @examples
+#' data(Smithsonian)
+#' Smithsonian
+NULL
+
