@@ -98,8 +98,10 @@ format_ch_vec <-
 
 format_selectors <- function(x, wdth = options()$width - 9, ...) {
   ## convert to character without the leading ~
-  x_items <- lapply(x, function(x)
-    as.character(x[-1]))
+  x_items <- lapply(x, function(x) {
+    as.character(get_expr(x))
+  })
+
   x_items <- unlist(x_items)
   format_ch_vec(x_items, width = wdth, sep = ", ")
 }
@@ -155,7 +157,8 @@ mod_call_args <- function(cl, args, removals = NULL) {
 #'  `dummy_names` generates a character vector the same length as
 #'  `lvl`,
 #' @keywords datagen
-#' @concept string_functions naming_functions
+#' @concept string_functions
+#' @concept naming_functions
 #' @examples
 #' names0(9, "x")
 #' names0(10, "x")
@@ -198,6 +201,8 @@ dummy_names <- function(var, lvl, ordinal = FALSE, sep = "_") {
 fun_calls <- function(f) {
   if (is.function(f)) {
     fun_calls(body(f))
+  } else if (is_quosure(f))  {
+    fun_calls(quo_get_expr(f))
   } else if (is.call(f)) {
     fname <- as.character(f[[1]])
     # Calls inside .Internal are special and shouldn't be included
