@@ -26,9 +26,9 @@
 #' @param res The [pls::plsr()] object is stored
 #'  here once this preprocessing step has be trained by
 #'  [prep.recipe()].
-#' @param num The number of components to retain (this will be 
-#'  deprecated in factor of `num_comp` in version 0.1.5). `num_comp` 
-#'  will override this option. 
+#' @param num The number of components to retain (this will be
+#'  deprecated in factor of `num_comp` in version 0.1.5). `num_comp`
+#'  will override this option.
 #' @param prefix A character string that will be the prefix to the
 #'  resulting new variables. See notes below.
 #' @return An updated version of `recipe` with the new step
@@ -36,7 +36,9 @@
 #'  `tidy` method, a tibble with columns `terms` (the
 #'  selectors or variables selected).
 #' @keywords datagen
-#' @concept preprocessing pls projection_methods
+#' @concept preprocessing
+#' @concept pls
+#' @concept projection_methods
 #' @export
 #' @details PLS is a supervised version of principal component
 #'  analysis that requires one or more numeric outcomes to compute
@@ -95,7 +97,7 @@ step_pls <-
            id = rand_id("pls")) {
     if (is.null(outcome))
       stop("`outcome` should select at least one column.", call. = FALSE)
-    if (!is.null(num)) 
+    if (!is.null(num))
       message("The argument `num` is deprecated in factor of `num_comp`. ",
               "`num` will be removed in next version.", call. = FALSE)
     recipes_pkg_check("pls")
@@ -119,7 +121,7 @@ step_pls <-
   }
 
 step_pls_new <-
-  function(terms, role, trained, num_comp, outcome, options, res, num, 
+  function(terms, role, trained, num_comp, outcome, options, res, num,
            prefix, skip, id) {
     step(
       subclass = "pls",
@@ -143,21 +145,28 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
   y_names <- terms_select(x$outcome, info = info)
   check_type(training[, c(y_names, x_names)])
 
-  if(length(y_names) == 1) {
+  if (length(y_names) == 1) {
     y_form <- y_names
   } else {
     y_form <- paste0(y_names, collapse = ",")
     y_form <- paste0("cbind(", y_form, ")")
   }
-  args <- list(formula = as.formula(paste(y_form, ".", sep = "~")),
-               data = training[, c(y_names, x_names)])
 
-  x$options$ncomp <- min(x$num_comp, length(x_names))
-  args <- c(args, x$options)
-  mod <- do.call(pls::plsr, args)
+  if (x$num_comp > 0) {
+    args <- list(formula = as.formula(paste(y_form, ".", sep = "~")),
+                 data = training[, c(y_names, x_names)])
 
-  if(!any(names(mod) == "scale"))
-    mod$scale <- NA
+    x$options$ncomp <- min(x$num_comp, length(x_names))
+    args <- c(args, x$options)
+    mod <- do.call(pls::plsr, args)
+
+    if (!any(names(mod) == "scale"))
+      mod$scale <- NA
+
+    res <- mod[c("projection", "Xmeans", "scale")]
+  } else {
+    res <- list(x_vars = x_names, y_vars = y_names)
+  }
 
   step_pls_new(
     terms = x$terms,
@@ -166,7 +175,7 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
     num_comp = x$num_comp,
     outcome = x$outcome,
     options = x$options,
-    res = mod[c("projection", "Xmeans", "scale")],
+    res = res,
     num = x$num_comp,
     prefix = x$prefix,
     skip = x$skip,
@@ -176,32 +185,37 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_pls <- function(object, new_data, ...) {
-  pls_vars <- rownames(object$res$projection)
-  n <- nrow(new_data)
-  input_data <- as.matrix(new_data[, pls_vars])
+  if (object$num_comp > 0) {
+    pls_vars <- rownames(object$res$projection)
+    n <- nrow(new_data)
+    input_data <- as.matrix(new_data[, pls_vars])
 
-  if(!all(is.na(object$res$scale)))
-    input_data <- sweep(input_data, 2, object$res$scale, "/")
+    if (!all(is.na(object$res$scale)))
+      input_data <- sweep(input_data, 2, object$res$scale, "/")
 
-  input_data <- sweep(input_data, 2, object$res$Xmeans, "-")
+    input_data <- sweep(input_data, 2, object$res$Xmeans, "-")
 
-  comps <- input_data %*% object$res$projection
-  comps <- check_name(comps, new_data, object)
-  new_data <- bind_cols(new_data, as_tibble(comps))
-  new_data <-
-    new_data[, !(colnames(new_data) %in% pls_vars), drop = FALSE]
-  if (!is_tibble(new_data))
-    new_data <- as_tibble(new_data)
+    comps <- input_data %*% object$res$projection
+    comps <- check_name(comps, new_data, object)
+    new_data <- bind_cols(new_data, as_tibble(comps))
+    new_data <-
+      new_data[, !(colnames(new_data) %in% pls_vars), drop = FALSE]
+    if (!is_tibble(new_data))
+      new_data <- as_tibble(new_data)
+  }
   new_data
 }
 
 
-print.step_pls <-
-  function(x, width = max(20, options()$width - 35), ...) {
+print.step_pls <- function(x, width = max(20, options()$width - 35), ...) {
+  if (x$num_comp == 0) {
+    cat("No PLS components were extracted.\n")
+  } else {
     cat("PLS feature extraction with ")
     printer(rownames(x$res$projection), x$terms, x$trained, width = width)
-    invisible(x)
   }
+  invisible(x)
+}
 
 
 #' @rdname step_pls
@@ -209,12 +223,16 @@ print.step_pls <-
 #' @export
 tidy.step_pls <- function(x, ...) {
   if (is_trained(x)) {
-    res <- as.data.frame(x$res$projection)
-    res <- stack(res)
-    res$terms <- rep(rownames(x$res$projection), ncol(x$res$projection))
-    names(res)[1:2] <- c("value", "component")
-    res <- res[, c("terms", "value", "component")]
-    res$component <- gsub("Comp ", "PLS", res$component)
+    if (x$num_comp > 0) {
+      res <- as.data.frame(x$res$projection)
+      res <- stack(res)
+      res$terms <- rep(rownames(x$res$projection), ncol(x$res$projection))
+      names(res)[1:2] <- c("value", "component")
+      res <- res[, c("terms", "value", "component")]
+      res$component <- gsub("Comp ", "PLS", res$component)
+    } else {
+      res <- tibble(terms = x$res$x_vars, value = na_dbl, component  = na_chr)
+    }
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names, value = na_dbl, component = na_chr)
