@@ -6,7 +6,8 @@
 #' @aliases recipe recipe.default recipe.formula
 #' @author Max Kuhn
 #' @keywords datagen
-#' @concept preprocessing model_specification
+#' @concept preprocessing
+#' @concept model_specification
 #' @export
 recipe <- function(x, ...)
   UseMethod("recipe")
@@ -272,7 +273,8 @@ form2args <- function(formula, data, ...) {
 #'   used).
 #' @author Max Kuhn
 #' @keywords datagen
-#' @concept preprocessing model_specification
+#' @concept preprocessing
+#' @concept model_specification
 #' @export
 prep   <- function(x, ...)
   UseMethod("prep")
@@ -472,7 +474,8 @@ prep.recipe <-
 #' @aliases bake bake.recipe
 #' @author Max Kuhn
 #' @keywords datagen
-#' @concept preprocessing model_specification
+#' @concept preprocessing
+#' @concept model_specification
 #' @export
 bake <- function(object, ...)
   UseMethod("bake")
@@ -532,24 +535,8 @@ bake.recipe <- function(object, new_data = NULL, ..., composition = "tibble") {
   # In case someone used the deprecated `newdata`:
   if (is.null(new_data) || is.null(ncol(new_data))) {
     if (any(names(terms) == "newdata")) {
-      warning("Please use `new_data` instead of `newdata` with `bake`. \nIn ",
-              "recipes versions >= 0.1.5, this will cause an error.",
-              call. = FALSE)
-      # If a single selector is passed in, it is now in `new_data`.
-      if (!is.null(match.call()$new_data)) {
-        slctr <- as_quosure(match.call()$new_data)
-      } else slctr <- NULL
-      new_data <- eval_tidy(terms$newdata)
-      if (length(terms) > 1) {
-        terms$newdata <- NULL
-        if (!is.null(slctr)) {
-          terms <- c(slctr, terms)
-        }
-      } else {
-        if (!is.null(slctr)) {
-          terms <- list(slctr)
-        } else terms <- quos()
-      }
+      stop("Please use `new_data` instead of `newdata` with `bake`.",
+           call. = FALSE)
     } else {
       stop("Please pass a data set to `new_data`.", call. = FALSE)
     }
