@@ -9,7 +9,7 @@ data("biomass")
 test_that("Recipe correctly identifies output variable", {
   raw_recipe <- recipe(HHV ~ ., data = biomass)
   var_info <- raw_recipe$var_info
-  expect_true(is.tibble(var_info))
+  expect_true(is_tibble(var_info))
   outcome_ind <- which(var_info$variable == "HHV")
   expect_true(var_info$role[outcome_ind] == "outcome")
   expect_true(all(var_info$role[-outcome_ind] == rep("predictor", ncol(biomass) - 1)))
@@ -114,41 +114,10 @@ test_that("bake without prep", {
 
 
 test_that("bake without newdata", {
-  # This will be deprecated in versions >= 0.1.5.9000
-  expect_false(
-    package_version(packageVersion("recipes")) > package_version("0.1.5.9000"),
-    "deprecate allowing `newdata` instead of `new_data`"
-  )
-
   rec <-  recipe(HHV ~ ., data = biomass) %>%
     step_center(all_numeric()) %>%
     step_scale(all_numeric()) %>%
     prep(training = biomass, retain = TRUE)
 
-  exp_1 <- bake(rec, new_data = biomass)
-  exp_2 <- bake(rec, new_data = biomass, all_predictors())
-  exp_3 <- bake(rec, new_data = biomass, all_predictors(), -all_nominal())
-
-  expect_error(bake(rec))
-
-  expect_warning(
-    obs_1 <- bake(rec, newdata = biomass),
-    "0.1.5"
-  )
-  expect_equal(obs_1, exp_1)
-  expect_equal(bake(rec, biomass), exp_1)
-
-  expect_warning(
-    obs_2 <- bake(rec, newdata = biomass, all_predictors()),
-    "0.1.5"
-  )
-  expect_equal(obs_2, exp_2)
-  expect_equal(bake(rec, biomass, all_predictors()), exp_2)
-
-  expect_warning(
-    obs_3 <- bake(rec, newdata = biomass, all_predictors(), -all_nominal()),
-    "0.1.5"
-  )
-  expect_equal(obs_3, exp_3)
-  expect_equal(bake(rec, biomass, all_predictors(), -all_nominal()), exp_3)
+  expect_error(bake(rec, newdata = biomass))
 })
